@@ -4,11 +4,11 @@ import webbrowser
 from pathlib import Path
 
 import click
-from click import Context
+from click import ClickException, Context
 
 from .client import VertexAIPipelinesClient
-from .config import PluginConfig
-from .constants import VERTEXAI_RUN_ID_TAG
+from .config import PluginConfig, RunConfig
+from .constants import KEDRO_VERTEXAI_BLOB_TEMP_DIR_NAME, VERTEXAI_RUN_ID_TAG
 from .context_helper import ContextHelper
 from .data_models import PipelineResult
 from .utils import materialize_dynamic_configuration, store_parameters_in_yaml
@@ -99,16 +99,21 @@ def run_once(
     """Deploy pipeline as a single run within given experiment
     Config can be specified in kubeflow.yml as well."""
     context_helper = ctx.obj["context_helper"]
-    config = context_helper.config.run_config
+    config: RunConfig = context_helper.config.run_config
     client: VertexAIPipelinesClient = context_helper.vertexai_client
 
-    client.run_once(
+    run = client.run_once(
         pipeline=pipeline,
         image=image if image else config.image,
         image_pull_policy=config.image_pull_policy,
         parameters=format_params(params),
     )
 
+    click.echo(
+        f"Intermediate data datasets will be stored in{os.linesep}"
+        f"gs://{config.root.strip('/')}/{KEDRO_VERTEXAI_BLOB_TEMP_DIR_NAME}/{run['displayName']}/*.bin"
+    )
+
     if wait_for_completion:
         result: PipelineResult = client.wait_for_completion(
             timeout_seconds
@@ -252,17 +257,12 @@ def init(ctx, project_id, region, with_github_actions: bool):
 @click.pass_context
 def mlflow_start(ctx, run_id: str, output: str):
     import mlflow
-    from kedro_mlflow.framework.context import get_mlflow_config
 
     try:
         kedro_context = ctx.obj["context_helper"].context
-        mlflow_conf = get_mlflow_config(kedro_context)
-        mlflow_conf.setup(kedro_context)
+        mlflow_conf = kedro_context.mlflow
     except AttributeError:
-        kedro_session = ctx.obj["context_helper"].session
-        with kedro_session:
-            mlflow_conf = get_mlflow_config(kedro_session)
-            mlflow_conf.setup()
+        raise ClickException("Could not read MLFlow config")
 
     run = mlflow.start_run(
         experiment_id=mlflow_conf.experiment.experiment_id, nested=False
