@@ -8,6 +8,7 @@ from tempfile import NamedTemporaryFile
 from typing import Dict, Set
 
 import kfp
+from kedro.framework.context import KedroContext
 from kedro.pipeline.node import Node
 from kfp.components.structures import (
     ComponentSpec,
@@ -19,14 +20,18 @@ from kfp.components.structures import (
 )
 from kfp.v2 import dsl
 
-from kedro_vertexai.config import RunConfig
+from kedro_vertexai.config import KedroVertexAIRunnerConfig, RunConfig
 from kedro_vertexai.constants import (
+    KEDRO_CONFIG_JOB_NAME,
+    KEDRO_CONFIG_RUN_ID,
     KEDRO_GLOBALS_PATTERN,
     KEDRO_VERTEXAI_DISABLE_CONFIG_HOOK,
+    KEDRO_VERTEXAI_RUNNER_CONFIG,
 )
 from kedro_vertexai.runtime_config import CONFIG_HOOK_DISABLED
 from kedro_vertexai.utils import clean_name, is_mlflow_enabled
 from kedro_vertexai.vertex_ai.io import generate_mlflow_inputs
+from kedro_vertexai.vertex_ai.runner import VertexAIPipelinesRunner
 
 
 class PipelineGenerator:
@@ -41,7 +46,7 @@ class PipelineGenerator:
         assert run_name, "run_name cannot be empty / None"
         self.run_name = run_name
         self.project_name = project_name
-        self.context = context
+        self.context: KedroContext = context
         self.run_config: RunConfig = config.run_config
         self.catalog = context.config_loader.get("catalog*")
 
@@ -49,7 +54,7 @@ class PipelineGenerator:
         """
         Returns Vertex-compatible pipeline name
         """
-        return self.project_name.lower().replace(" ", "-")
+        return self.project_name.lower().replace(" ", "-").replace("_", "-")
 
     def generate_pipeline(self, pipeline, image, image_pull_policy, token):
         """
@@ -73,9 +78,9 @@ class PipelineGenerator:
             description=self.run_config.description,
         )
         def convert_kedro_pipeline_to_kfp() -> None:
-            node_dependencies = self.context.pipelines.get(
-                pipeline
-            ).node_dependencies
+            from kedro.framework.project import pipelines
+
+            node_dependencies = pipelines[pipeline].node_dependencies
             kfp_ops = self._build_kfp_ops(
                 node_dependencies, image, pipeline, token
             )
@@ -94,13 +99,17 @@ class PipelineGenerator:
             for ha in host_aliases
         )
 
-    def _create_mlflow_op(self, image, tracking_token) -> dsl.ContainerOp:
+    def _create_mlflow_op(
+        self, image, tracking_token, should_add_params
+    ) -> dsl.ContainerOp:
+
         mlflow_command = " ".join(
             [
                 self._generate_hosts_file(),
                 "mkdir --parents",
                 "`dirname {{$.outputs.parameters['output'].output_file}}`",
                 "&&",
+                self._generate_params_command(should_add_params),
                 "MLFLOW_TRACKING_TOKEN={{$.inputs.parameters['mlflow_tracking_token']}}",
                 f"kedro vertexai -e {self.context.env} mlflow-start",
                 "--output {{$.outputs.parameters['output'].output_file}}",
@@ -140,10 +149,12 @@ class PipelineGenerator:
         """Build kfp container graph from Kedro node dependencies."""
         kfp_ops = {}
 
+        should_add_params = len(self.context.params) > 0
+
         mlflow_enabled = is_mlflow_enabled()
         if mlflow_enabled:
             kfp_ops["mlflow-start-run"] = self._create_mlflow_op(
-                image, tracking_token
+                image, tracking_token, should_add_params
             )
 
         for node in node_dependencies:
@@ -156,16 +167,21 @@ class PipelineGenerator:
                 else []
             )
 
-            should_add_params = len(self.context.params) > 0
+            runner_config = KedroVertexAIRunnerConfig(
+                storage_root=self.run_config.root
+            )
 
             kedro_command = " ".join(
                 [
                     f"{KEDRO_VERTEXAI_DISABLE_CONFIG_HOOK}={'true' if CONFIG_HOOK_DISABLED else 'false'}",
-                    f"KEDRO_CONFIG_RUN_ID={dsl.PIPELINE_JOB_ID_PLACEHOLDER}",
+                    f"{KEDRO_CONFIG_RUN_ID}={dsl.PIPELINE_JOB_ID_PLACEHOLDER}",
+                    f"{KEDRO_CONFIG_JOB_NAME}={dsl.PIPELINE_JOB_NAME_PLACEHOLDER}",
+                    f"{KEDRO_VERTEXAI_RUNNER_CONFIG}='{runner_config.json()}'",
                     self._globals_env(),
                     f"kedro run -e {self.context.env}",
                     f"--pipeline {pipeline}",
                     f'--node "{node.name}"',
+                    f"--runner {VertexAIPipelinesRunner.runner_name()}",
                     "--config config.yaml" if should_add_params else "",
                 ]
             )
